/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.common.constant;

import org.springblade.core.launch.constant.AppConstant;

/**
 * 通用常量
 *
 * @author Chill
 */
public interface CommonConstant {

	/**
	 * app name
	 */
	String APPLICATION_NAME = AppConstant.APPLICATION_NAME_PREFIX + "api";

	/**
	 * sword 系统名
	 */
	String SWORD_NAME = "sword";

	/**
	 * saber 系统名
	 */
	String SABER_NAME = "saber";

	/**
	 * 顶级父节点id
	 */
	Long TOP_PARENT_ID = 0L;

	/**
	 * 顶级父节点名称
	 */
	String TOP_PARENT_NAME = "顶级";

	/**
	 * 未封存状态值
	 */
	Integer NOT_SEALED_ID = 0;

	/**
	 * 默认密码
	 */
	String DEFAULT_PASSWORD = "123456";

	/**
	 * 默认密码参数值
	 */
	String DEFAULT_PARAM_PASSWORD = "account.initPassword";

	/**
	 * 默认排序字段
	 */
	String SORT_FIELD = "sort";

	/**
	 * 数据权限类型
	 */
	Integer DATA_SCOPE_CATEGORY = 1;

	/**
	 * 接口权限类型
	 */
	Integer API_SCOPE_CATEGORY = 2;


	String API_URL = "v1";

	/**
	 * 默认用户头像
	 */
	String DEFAULT_AVATAR = "user:default:avatar";

	/**
	 * 默认角色
	 */
	String DEFAULT_ROLD = "user:default:role";


	/**
	 * 默认部门
	 */
	String DEFAULT_DEPT = "user:default:dept";

	/**
	 * 默认岗位
	 */
	String DEFAULT_POST = "user:default:post";

	/**
	 * 默认信誉分
	 */
	String DEFAULT_CREDIT_SCORE = "user:default:creditScore";

	/**
	 * 广告轮播默认条数
	 */
	String DEFAULT_ADS_LIMIT = "default:ads:limit";

	/**
	 * 服务器服务域名
	 */
	String DEFAULT_SERVICE_DOMAIN = "default:service:domain";

	/**
	 * 邀请好友注册完善资料（+5信誉分）
	 */
	String SCORE_USER_REGISTER = "score:user:register";

	/**
	 * 500信誉分以上或含有500信誉分 - 完成进货+2信誉分，
	 */
	String SCORE_CONSIGN_OVER = "score:consign:in";

	/**
	 * 500信誉分以上或含有500信誉分 - 邀请好友注册完善资料+1信誉分
	 */
	String SCORE_CONSIGN_REGISTER = "score:consign:register";


	/**
	 * 增益时间
	 */
	String GAIN_CONSIGN_TIME = "gain:consign:time";

	/**
	 * 提现额度
	 */
	String NORMAL_WITHDRAWAL_CAPS = "normal:withdrawal:caps";

	/**
	 * 免费领酒商品
	 */
	String FREE_WINE_GOODS_ID = "free:wine:goods:id";

	/**
	 * 免费领酒商品的商品的物流包装费
	 */
	String FREE_WINE_GOODS_WL_PRICE = "free:wine:goods:wl:price";


	String ALI_PAY = "aliPay";

	String WX_PAY = "wxPay";
}
