/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.activities.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.activities.entity.Activities;
import org.springblade.modules.activities.vo.ActivitiesVO;
import org.springblade.modules.activities.wrapper.ActivitiesWrapper;
import org.springblade.modules.activities.service.IActivitiesService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 活动专区表 控制器
 *
 * @author BladeX
 * @since 2023-04-27
 */
@RestController
@AllArgsConstructor
@RequestMapping("activities/activities")
@Api(value = "活动专区表", tags = "活动专区表接口")
public class ActivitiesController extends BladeController {

	private final IActivitiesService activitiesService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入activities")
	public R<ActivitiesVO> detail(Activities activities) {
		Activities detail = activitiesService.getOne(Condition.getQueryWrapper(activities));
		return R.data(ActivitiesWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 活动专区表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入activities")
	public R<IPage<ActivitiesVO>> list(Activities activities, Query query) {
		IPage<Activities> pages = activitiesService.page(Condition.getPage(query), Condition.getQueryWrapper(activities));
		return R.data(ActivitiesWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 活动专区表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入activities")
	public R<IPage<ActivitiesVO>> page(ActivitiesVO activities, Query query) {
		IPage<ActivitiesVO> pages = activitiesService.selectActivitiesPage(Condition.getPage(query), activities);
		return R.data(pages);
	}

	/**
	 * 新增 活动专区表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入activities")
	public R save(@Valid @RequestBody Activities activities) {
		return R.status(activitiesService.save(activities));
	}

	/**
	 * 修改 活动专区表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入activities")
	public R update(@Valid @RequestBody Activities activities) {
		return R.status(activitiesService.updateById(activities));
	}

	/**
	 * 新增或修改 活动专区表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入activities")
	public R submit(@Valid @RequestBody Activities activities) {
		return R.status(activitiesService.saveOrUpdate(activities));
	}

	
	/**
	 * 删除 活动专区表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(activitiesService.removeByIds(Func.toLongList(ids)));
	}

	
}
