/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.activities.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.activities.entity.Prize;
import org.springblade.modules.activities.vo.PrizeVO;
import org.springblade.modules.activities.wrapper.PrizeWrapper;
import org.springblade.modules.activities.service.IPrizeService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 奖品表 控制器
 *
 * @author BladeX
 * @since 2023-05-26
 */
@RestController
@AllArgsConstructor
@RequestMapping("activities/prize")
@Api(value = "奖品表", tags = "奖品表接口")
public class PrizeController extends BladeController {

	private final IPrizeService prizeService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入prize")
	public R<PrizeVO> detail(Prize prize) {
		Prize detail = prizeService.getOne(Condition.getQueryWrapper(prize));
		return R.data(PrizeWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 奖品表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入prize")
	public R<IPage<PrizeVO>> list(Prize prize, Query query) {
		IPage<Prize> pages = prizeService.page(Condition.getPage(query), Condition.getQueryWrapper(prize));
		return R.data(PrizeWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 奖品表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入prize")
	public R<IPage<PrizeVO>> page(PrizeVO prize, Query query) {
		IPage<PrizeVO> pages = prizeService.selectPrizePage(Condition.getPage(query), prize);
		return R.data(pages);
	}

	/**
	 * 新增 奖品表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入prize")
	public R save(@Valid @RequestBody Prize prize) {
		return R.status(prizeService.save(prize));
	}

	/**
	 * 修改 奖品表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入prize")
	public R update(@Valid @RequestBody Prize prize) {
		return R.status(prizeService.updateById(prize));
	}

	/**
	 * 新增或修改 奖品表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入prize")
	public R submit(@Valid @RequestBody Prize prize) {
		return R.status(prizeService.saveOrUpdate(prize));
	}

	
	/**
	 * 删除 奖品表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(prizeService.removeByIds(Func.toLongList(ids)));
	}

	
}
