/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.activities.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.activities.entity.PrizeRecord;
import org.springblade.modules.activities.vo.PrizeRecordVO;
import org.springblade.modules.activities.wrapper.PrizeRecordWrapper;
import org.springblade.modules.activities.service.IPrizeRecordService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 中奖记录表 控制器
 *
 * @author BladeX
 * @since 2023-05-25
 */
@RestController
@AllArgsConstructor
@RequestMapping("activities/prizerecord")
@Api(value = "中奖记录表", tags = "中奖记录表接口")
public class PrizeRecordController extends BladeController {

	private final IPrizeRecordService prizeRecordService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入prizeRecord")
	public R<PrizeRecordVO> detail(PrizeRecord prizeRecord) {
		PrizeRecord detail = prizeRecordService.getOne(Condition.getQueryWrapper(prizeRecord));
		return R.data(PrizeRecordWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 中奖记录表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入prizeRecord")
	public R<IPage<PrizeRecordVO>> list(PrizeRecord prizeRecord, Query query) {
		IPage<PrizeRecord> pages = prizeRecordService.page(Condition.getPage(query), Condition.getQueryWrapper(prizeRecord));
		return R.data(PrizeRecordWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 中奖记录表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入prizeRecord")
	public R<IPage<PrizeRecordVO>> page(PrizeRecordVO prizeRecord, Query query) {
		IPage<PrizeRecordVO> pages = prizeRecordService.selectPrizeRecordPage(Condition.getPage(query), prizeRecord);
		return R.data(pages);
	}

	/**
	 * 新增 中奖记录表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入prizeRecord")
	public R save(@Valid @RequestBody PrizeRecord prizeRecord) {
		return R.status(prizeRecordService.save(prizeRecord));
	}

	/**
	 * 修改 中奖记录表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入prizeRecord")
	public R update(@Valid @RequestBody PrizeRecord prizeRecord) {
		return R.status(prizeRecordService.updateById(prizeRecord));
	}

	/**
	 * 新增或修改 中奖记录表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入prizeRecord")
	public R submit(@Valid @RequestBody PrizeRecord prizeRecord) {
		return R.status(prizeRecordService.saveOrUpdate(prizeRecord));
	}

	
	/**
	 * 删除 中奖记录表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(prizeRecordService.removeByIds(Func.toLongList(ids)));
	}

	
}
