/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.activities.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.activities.entity.SignIn;
import org.springblade.modules.activities.vo.SignInVO;
import org.springblade.modules.activities.wrapper.SignInWrapper;
import org.springblade.modules.activities.service.ISignInService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 签到信息表 控制器
 *
 * @author BladeX
 * @since 2023-05-05
 */
@RestController
@AllArgsConstructor
@RequestMapping("activities/signin")
@Api(value = "签到信息表", tags = "签到信息表接口")
public class SignInController extends BladeController {

	private final ISignInService signInService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入signIn")
	public R<SignInVO> detail(SignIn signIn) {
		SignIn detail = signInService.getOne(Condition.getQueryWrapper(signIn));
		return R.data(SignInWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 签到信息表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入signIn")
	public R<IPage<SignInVO>> list(SignIn signIn, Query query) {
		IPage<SignIn> pages = signInService.page(Condition.getPage(query), Condition.getQueryWrapper(signIn));
		return R.data(SignInWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 签到信息表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入signIn")
	public R<IPage<SignInVO>> page(SignInVO signIn, Query query) {
		IPage<SignInVO> pages = signInService.selectSignInPage(Condition.getPage(query), signIn);
		return R.data(pages);
	}

	/**
	 * 新增 签到信息表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入signIn")
	public R save(@Valid @RequestBody SignIn signIn) {
		return R.status(signInService.save(signIn));
	}

	/**
	 * 修改 签到信息表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入signIn")
	public R update(@Valid @RequestBody SignIn signIn) {
		return R.status(signInService.updateById(signIn));
	}

	/**
	 * 新增或修改 签到信息表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入signIn")
	public R submit(@Valid @RequestBody SignIn signIn) {
		return R.status(signInService.saveOrUpdate(signIn));
	}

	
	/**
	 * 删除 签到信息表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(signInService.removeByIds(Func.toLongList(ids)));
	}

	
}
