/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.activities.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.activities.entity.SignInRecord;
import org.springblade.modules.activities.vo.SignInRecordVO;
import org.springblade.modules.activities.wrapper.SignInRecordWrapper;
import org.springblade.modules.activities.service.ISignInRecordService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 签到记录表 控制器
 *
 * @author BladeX
 * @since 2023-05-05
 */
@RestController
@AllArgsConstructor
@RequestMapping("activities/signinrecord")
@Api(value = "签到记录表", tags = "签到记录表接口")
public class SignInRecordController extends BladeController {

	private final ISignInRecordService signInRecordService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入signInRecord")
	public R<SignInRecordVO> detail(SignInRecord signInRecord) {
		SignInRecord detail = signInRecordService.getOne(Condition.getQueryWrapper(signInRecord));
		return R.data(SignInRecordWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 签到记录表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入signInRecord")
	public R<IPage<SignInRecordVO>> list(SignInRecord signInRecord, Query query) {
		IPage<SignInRecord> pages = signInRecordService.page(Condition.getPage(query), Condition.getQueryWrapper(signInRecord));
		return R.data(SignInRecordWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 签到记录表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入signInRecord")
	public R<IPage<SignInRecordVO>> page(SignInRecordVO signInRecord, Query query) {
		IPage<SignInRecordVO> pages = signInRecordService.selectSignInRecordPage(Condition.getPage(query), signInRecord);
		return R.data(pages);
	}

	/**
	 * 新增 签到记录表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入signInRecord")
	public R save(@Valid @RequestBody SignInRecord signInRecord) {
		return R.status(signInRecordService.save(signInRecord));
	}

	/**
	 * 修改 签到记录表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入signInRecord")
	public R update(@Valid @RequestBody SignInRecord signInRecord) {
		return R.status(signInRecordService.updateById(signInRecord));
	}

	/**
	 * 新增或修改 签到记录表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入signInRecord")
	public R submit(@Valid @RequestBody SignInRecord signInRecord) {
		return R.status(signInRecordService.saveOrUpdate(signInRecord));
	}

	
	/**
	 * 删除 签到记录表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(signInRecordService.removeByIds(Func.toLongList(ids)));
	}

	
}
