/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.activities.wrapper;

import org.springblade.core.mp.support.BaseEntityWrapper;
import org.springblade.core.tool.utils.BeanUtil;
import org.springblade.modules.activities.entity.SignIn;
import org.springblade.modules.activities.vo.SignInVO;

import java.time.LocalDateTime;
import java.util.Objects;

/**
 * 签到信息表包装类,返回视图层所需的字段
 *
 * @author BladeX
 * @since 2023-05-05
 */
public class SignInWrapper extends BaseEntityWrapper<SignIn, SignInVO>  {

	public static SignInWrapper build() {
		return new SignInWrapper();
 	}

	@Override
	public SignInVO entityVO(SignIn signIn) {
		SignInVO signInVO = Objects.requireNonNull(BeanUtil.copy(signIn, SignInVO.class));
		LocalDateTime now = LocalDateTime.now();
		// 最后签到时间不为空并且等于今天，则不能继续签到
		signInVO.setCanSignIn(signInVO.getLastSignInTime() == null || !signInVO.getLastSignInTime().toLocalDate().equals(now.toLocalDate()));
		return signInVO;
	}
}
