/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.auction.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.auction.entity.AuctionApply;
import org.springblade.modules.auction.vo.AuctionApplyVO;
import org.springblade.modules.auction.wrapper.AuctionApplyWrapper;
import org.springblade.modules.auction.service.IAuctionApplyService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 竞拍报名表 控制器
 *
 * @author BladeX
 * @since 2023-02-14
 */
@RestController
@AllArgsConstructor
@RequestMapping("auction/auctionapply")
@Api(value = "竞拍报名表", tags = "竞拍报名表接口")
public class AuctionApplyController extends BladeController {

	private final IAuctionApplyService auctionApplyService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入auctionApply")
	public R<AuctionApplyVO> detail(AuctionApply auctionApply) {
		AuctionApply detail = auctionApplyService.getOne(Condition.getQueryWrapper(auctionApply));
		return R.data(AuctionApplyWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 竞拍报名表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入auctionApply")
	public R<IPage<AuctionApplyVO>> list(AuctionApply auctionApply, Query query) {
		IPage<AuctionApply> pages = auctionApplyService.page(Condition.getPage(query), Condition.getQueryWrapper(auctionApply));
		return R.data(AuctionApplyWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 竞拍报名表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入auctionApply")
	public R<IPage<AuctionApplyVO>> page(AuctionApplyVO auctionApply, Query query) {
		IPage<AuctionApplyVO> pages = auctionApplyService.selectAuctionApplyPage(Condition.getPage(query), auctionApply);
		return R.data(pages);
	}

	/**
	 * 新增 竞拍报名表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入auctionApply")
	public R save(@Valid @RequestBody AuctionApply auctionApply) {
		return R.status(auctionApplyService.save(auctionApply));
	}

	/**
	 * 修改 竞拍报名表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入auctionApply")
	public R update(@Valid @RequestBody AuctionApply auctionApply) {
		return R.status(auctionApplyService.updateById(auctionApply));
	}

	/**
	 * 新增或修改 竞拍报名表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入auctionApply")
	public R submit(@Valid @RequestBody AuctionApply auctionApply) {
		return R.status(auctionApplyService.saveOrUpdate(auctionApply));
	}

	
	/**
	 * 删除 竞拍报名表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(auctionApplyService.removeByIds(Func.toLongList(ids)));
	}

	
}
