/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.auction.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.auction.entity.AuctionGoods;
import org.springblade.modules.auction.vo.AuctionGoodsVO;
import org.springblade.modules.auction.wrapper.AuctionGoodsWrapper;
import org.springblade.modules.auction.service.IAuctionGoodsService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 拍卖商品表 控制器
 *
 * @author BladeX
 * @since 2023-02-14
 */
@RestController
@AllArgsConstructor
@RequestMapping("auction/auctiongoods")
@Api(value = "拍卖商品表", tags = "拍卖商品表接口")
public class AuctionGoodsController extends BladeController {

	private final IAuctionGoodsService auctionGoodsService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入auctionGoods")
	public R<AuctionGoodsVO> detail(AuctionGoods auctionGoods) {
		AuctionGoods detail = auctionGoodsService.getOne(Condition.getQueryWrapper(auctionGoods));
		return R.data(AuctionGoodsWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 拍卖商品表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入auctionGoods")
	public R<IPage<AuctionGoodsVO>> list(AuctionGoods auctionGoods, Query query) {
		IPage<AuctionGoods> pages = auctionGoodsService.page(Condition.getPage(query), Condition.getQueryWrapper(auctionGoods));
		return R.data(AuctionGoodsWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 拍卖商品表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入auctionGoods")
	public R<IPage<AuctionGoodsVO>> page(AuctionGoodsVO auctionGoods, Query query) {
		IPage<AuctionGoodsVO> pages = auctionGoodsService.selectAuctionGoodsPage(Condition.getPage(query), auctionGoods);
		return R.data(pages);
	}

	/**
	 * 新增 拍卖商品表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入auctionGoods")
	public R save(@Valid @RequestBody AuctionGoods auctionGoods) {
		return R.status(auctionGoodsService.save(auctionGoods));
	}

	/**
	 * 修改 拍卖商品表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入auctionGoods")
	public R update(@Valid @RequestBody AuctionGoods auctionGoods) {
		return R.status(auctionGoodsService.updateById(auctionGoods));
	}

	/**
	 * 新增或修改 拍卖商品表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入auctionGoods")
	public R submit(@Valid @RequestBody AuctionGoods auctionGoods) {
		return R.status(auctionGoodsService.saveOrUpdate(auctionGoods));
	}

	
	/**
	 * 删除 拍卖商品表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(auctionGoodsService.removeByIds(Func.toLongList(ids)));
	}

	
}
