/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.auction.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.auction.entity.AuctionRecord;
import org.springblade.modules.auction.vo.AuctionRecordVO;
import org.springblade.modules.auction.wrapper.AuctionRecordWrapper;
import org.springblade.modules.auction.service.IAuctionRecordService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 竞拍记录表 控制器
 *
 * @author BladeX
 * @since 2023-02-14
 */
@RestController
@AllArgsConstructor
@RequestMapping("auction/auctionrecord")
@Api(value = "竞拍记录表", tags = "竞拍记录表接口")
public class AuctionRecordController extends BladeController {

	private final IAuctionRecordService auctionRecordService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入auctionRecord")
	public R<AuctionRecordVO> detail(AuctionRecord auctionRecord) {
		AuctionRecord detail = auctionRecordService.getOne(Condition.getQueryWrapper(auctionRecord));
		return R.data(AuctionRecordWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 竞拍记录表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入auctionRecord")
	public R<IPage<AuctionRecordVO>> list(AuctionRecord auctionRecord, Query query) {
		IPage<AuctionRecord> pages = auctionRecordService.page(Condition.getPage(query), Condition.getQueryWrapper(auctionRecord));
		return R.data(AuctionRecordWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 竞拍记录表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入auctionRecord")
	public R<IPage<AuctionRecordVO>> page(AuctionRecordVO auctionRecord, Query query) {
		IPage<AuctionRecordVO> pages = auctionRecordService.selectAuctionRecordPage(Condition.getPage(query), auctionRecord);
		return R.data(pages);
	}

	/**
	 * 新增 竞拍记录表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入auctionRecord")
	public R save(@Valid @RequestBody AuctionRecord auctionRecord) {
		return R.status(auctionRecordService.save(auctionRecord));
	}

	/**
	 * 修改 竞拍记录表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入auctionRecord")
	public R update(@Valid @RequestBody AuctionRecord auctionRecord) {
		return R.status(auctionRecordService.updateById(auctionRecord));
	}

	/**
	 * 新增或修改 竞拍记录表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入auctionRecord")
	public R submit(@Valid @RequestBody AuctionRecord auctionRecord) {
		return R.status(auctionRecordService.saveOrUpdate(auctionRecord));
	}

	
	/**
	 * 删除 竞拍记录表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(auctionRecordService.removeByIds(Func.toLongList(ids)));
	}

	
}
