/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.auction.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.auction.entity.AuctionSpecialGoods;
import org.springblade.modules.auction.vo.AuctionSpecialGoodsVO;
import org.springblade.modules.auction.wrapper.AuctionSpecialGoodsWrapper;
import org.springblade.modules.auction.service.IAuctionSpecialGoodsService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 竞拍专场拍品关联表 控制器
 *
 * @author BladeX
 * @since 2023-02-14
 */
@RestController
@AllArgsConstructor
@RequestMapping("auction/auctionspecialgoods")
@Api(value = "竞拍专场拍品关联表", tags = "竞拍专场拍品关联表接口")
public class AuctionSpecialGoodsController extends BladeController {

	private final IAuctionSpecialGoodsService auctionSpecialGoodsService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入auctionSpecialGoods")
	public R<AuctionSpecialGoodsVO> detail(AuctionSpecialGoods auctionSpecialGoods) {
		AuctionSpecialGoods detail = auctionSpecialGoodsService.getOne(Condition.getQueryWrapper(auctionSpecialGoods));
		return R.data(AuctionSpecialGoodsWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 竞拍专场拍品关联表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入auctionSpecialGoods")
	public R<IPage<AuctionSpecialGoodsVO>> list(AuctionSpecialGoods auctionSpecialGoods, Query query) {
		IPage<AuctionSpecialGoods> pages = auctionSpecialGoodsService.page(Condition.getPage(query), Condition.getQueryWrapper(auctionSpecialGoods));
		return R.data(AuctionSpecialGoodsWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 竞拍专场拍品关联表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入auctionSpecialGoods")
	public R<IPage<AuctionSpecialGoodsVO>> page(AuctionSpecialGoodsVO auctionSpecialGoods, Query query) {
		IPage<AuctionSpecialGoodsVO> pages = auctionSpecialGoodsService.selectAuctionSpecialGoodsPage(Condition.getPage(query), auctionSpecialGoods);
		return R.data(pages);
	}

	/**
	 * 新增 竞拍专场拍品关联表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入auctionSpecialGoods")
	public R save(@Valid @RequestBody AuctionSpecialGoods auctionSpecialGoods) {
		return R.status(auctionSpecialGoodsService.save(auctionSpecialGoods));
	}

	/**
	 * 修改 竞拍专场拍品关联表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入auctionSpecialGoods")
	public R update(@Valid @RequestBody AuctionSpecialGoods auctionSpecialGoods) {
		return R.status(auctionSpecialGoodsService.updateById(auctionSpecialGoods));
	}

	/**
	 * 新增或修改 竞拍专场拍品关联表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入auctionSpecialGoods")
	public R submit(@Valid @RequestBody AuctionSpecialGoods auctionSpecialGoods) {
		return R.status(auctionSpecialGoodsService.saveOrUpdate(auctionSpecialGoods));
	}

	
	/**
	 * 删除 竞拍专场拍品关联表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(auctionSpecialGoodsService.removeByIds(Func.toLongList(ids)));
	}

	
}
