/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.custom.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.custom.entity.BottleBodyLabel;
import org.springblade.modules.custom.vo.BottleBodyLabelVO;
import org.springblade.modules.custom.service.IBottleBodyLabelService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 酒瓶标签表 控制器
 *
 * @author BladeX
 * @since 2023-05-17
 */
@RestController
@AllArgsConstructor
@RequestMapping("custom/bottlebodylabel")
@Api(value = "酒瓶标签表", tags = "酒瓶标签表接口")
public class BottleBodyLabelController extends BladeController {

	private final IBottleBodyLabelService bottleBodyLabelService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入bottleBodyLabel")
	public R<BottleBodyLabel> detail(BottleBodyLabel bottleBodyLabel) {
		BottleBodyLabel detail = bottleBodyLabelService.getOne(Condition.getQueryWrapper(bottleBodyLabel));
		return R.data(detail);
	}

	/**
	 * 分页 酒瓶标签表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入bottleBodyLabel")
	public R<IPage<BottleBodyLabel>> list(BottleBodyLabel bottleBodyLabel, Query query) {
		IPage<BottleBodyLabel> pages = bottleBodyLabelService.page(Condition.getPage(query), Condition.getQueryWrapper(bottleBodyLabel));
		return R.data(pages);
	}

	/**
	 * 自定义分页 酒瓶标签表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入bottleBodyLabel")
	public R<IPage<BottleBodyLabelVO>> page(BottleBodyLabelVO bottleBodyLabel, Query query) {
		IPage<BottleBodyLabelVO> pages = bottleBodyLabelService.selectBottleBodyLabelPage(Condition.getPage(query), bottleBodyLabel);
		return R.data(pages);
	}

	/**
	 * 新增 酒瓶标签表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入bottleBodyLabel")
	public R save(@Valid @RequestBody BottleBodyLabel bottleBodyLabel) {
		return R.status(bottleBodyLabelService.save(bottleBodyLabel));
	}

	/**
	 * 修改 酒瓶标签表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入bottleBodyLabel")
	public R update(@Valid @RequestBody BottleBodyLabel bottleBodyLabel) {
		return R.status(bottleBodyLabelService.updateById(bottleBodyLabel));
	}

	/**
	 * 新增或修改 酒瓶标签表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入bottleBodyLabel")
	public R submit(@Valid @RequestBody BottleBodyLabel bottleBodyLabel) {
		return R.status(bottleBodyLabelService.saveOrUpdate(bottleBodyLabel));
	}

	
	/**
	 * 删除 酒瓶标签表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(bottleBodyLabelService.removeByIds(Func.toLongList(ids)));
	}

	
}
