/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.custom.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.custom.entity.ManufacturerCert;
import org.springblade.modules.custom.vo.ManufacturerCertVO;
import org.springblade.modules.custom.service.IManufacturerCertService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 酒厂资质表 控制器
 *
 * @author BladeX
 * @since 2023-05-18
 */
@RestController
@AllArgsConstructor
@RequestMapping("custom/manufacturercert")
@Api(value = "酒厂资质表", tags = "酒厂资质表接口")
public class ManufacturerCertController extends BladeController {

	private final IManufacturerCertService manufacturerCertService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入manufacturerCert")
	public R<ManufacturerCert> detail(ManufacturerCert manufacturerCert) {
		ManufacturerCert detail = manufacturerCertService.getOne(Condition.getQueryWrapper(manufacturerCert));
		return R.data(detail);
	}

	/**
	 * 分页 酒厂资质表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入manufacturerCert")
	public R<IPage<ManufacturerCert>> list(ManufacturerCert manufacturerCert, Query query) {
		IPage<ManufacturerCert> pages = manufacturerCertService.page(Condition.getPage(query), Condition.getQueryWrapper(manufacturerCert));
		return R.data(pages);
	}

	/**
	 * 自定义分页 酒厂资质表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入manufacturerCert")
	public R<IPage<ManufacturerCertVO>> page(ManufacturerCertVO manufacturerCert, Query query) {
		IPage<ManufacturerCertVO> pages = manufacturerCertService.selectManufacturerCertPage(Condition.getPage(query), manufacturerCert);
		return R.data(pages);
	}

	/**
	 * 新增 酒厂资质表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入manufacturerCert")
	public R save(@Valid @RequestBody ManufacturerCert manufacturerCert) {
		return R.status(manufacturerCertService.save(manufacturerCert));
	}

	/**
	 * 修改 酒厂资质表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入manufacturerCert")
	public R update(@Valid @RequestBody ManufacturerCert manufacturerCert) {
		return R.status(manufacturerCertService.updateById(manufacturerCert));
	}

	/**
	 * 新增或修改 酒厂资质表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入manufacturerCert")
	public R submit(@Valid @RequestBody ManufacturerCert manufacturerCert) {
		return R.status(manufacturerCertService.saveOrUpdate(manufacturerCert));
	}

	
	/**
	 * 删除 酒厂资质表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(manufacturerCertService.removeByIds(Func.toLongList(ids)));
	}

	
}
