/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.custom.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.custom.entity.ManufacturerLabel;
import org.springblade.modules.custom.vo.ManufacturerLabelVO;
import org.springblade.modules.custom.service.IManufacturerLabelService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 酒厂标签关系表 控制器
 *
 * @author BladeX
 * @since 2023-05-18
 */
@RestController
@AllArgsConstructor
@RequestMapping("custom/manufacturerlabel")
@Api(value = "酒厂标签关系表", tags = "酒厂标签关系表接口")
public class ManufacturerLabelController extends BladeController {

	private final IManufacturerLabelService manufacturerLabelService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入manufacturerLabel")
	public R<ManufacturerLabel> detail(ManufacturerLabel manufacturerLabel) {
		ManufacturerLabel detail = manufacturerLabelService.getOne(Condition.getQueryWrapper(manufacturerLabel));
		return R.data(detail);
	}

	/**
	 * 分页 酒厂标签关系表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入manufacturerLabel")
	public R<IPage<ManufacturerLabel>> list(ManufacturerLabel manufacturerLabel, Query query) {
		IPage<ManufacturerLabel> pages = manufacturerLabelService.page(Condition.getPage(query), Condition.getQueryWrapper(manufacturerLabel));
		return R.data(pages);
	}

	/**
	 * 自定义分页 酒厂标签关系表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入manufacturerLabel")
	public R<IPage<ManufacturerLabelVO>> page(ManufacturerLabelVO manufacturerLabel, Query query) {
		IPage<ManufacturerLabelVO> pages = manufacturerLabelService.selectManufacturerLabelPage(Condition.getPage(query), manufacturerLabel);
		return R.data(pages);
	}

	/**
	 * 新增 酒厂标签关系表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入manufacturerLabel")
	public R save(@Valid @RequestBody ManufacturerLabel manufacturerLabel) {
		return R.status(manufacturerLabelService.save(manufacturerLabel));
	}

	/**
	 * 修改 酒厂标签关系表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入manufacturerLabel")
	public R update(@Valid @RequestBody ManufacturerLabel manufacturerLabel) {
		return R.status(manufacturerLabelService.updateById(manufacturerLabel));
	}

	/**
	 * 新增或修改 酒厂标签关系表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入manufacturerLabel")
	public R submit(@Valid @RequestBody ManufacturerLabel manufacturerLabel) {
		return R.status(manufacturerLabelService.saveOrUpdate(manufacturerLabel));
	}

	
	/**
	 * 删除 酒厂标签关系表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(manufacturerLabelService.removeByIds(Func.toLongList(ids)));
	}

	
}
