/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.custom.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.custom.entity.WineCase;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.custom.entity.SpecialBaseWine;
import org.springblade.modules.custom.vo.SpecialBaseWineVO;
import org.springblade.modules.custom.wrapper.SpecialBaseWineWrapper;
import org.springblade.modules.custom.service.ISpecialBaseWineService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 特调基酒 控制器
 *
 * @author BladeX
 * @since 2023-06-05
 */
@RestController
@AllArgsConstructor
@RequestMapping("custom/specialbasewine")
@Api(value = "特调基酒", tags = "特调基酒接口")
public class SpecialBaseWineController extends BladeController {

	private final ISpecialBaseWineService specialBaseWineService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入specialBaseWine")
	public R<SpecialBaseWineVO> detail(SpecialBaseWine specialBaseWine) {
		SpecialBaseWine detail = specialBaseWineService.getOne(Condition.getQueryWrapper(specialBaseWine));
		return R.data(SpecialBaseWineWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 特调基酒
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入specialBaseWine")
	public R<IPage<SpecialBaseWineVO>> list(SpecialBaseWine specialBaseWine, Query query) {
		QueryWrapper<SpecialBaseWine> queryWrapper = Condition.getQueryWrapper(specialBaseWine);
		if (!AuthUtil.getUserRole().contains("admin")) {
			queryWrapper.eq("create_user_id", AuthUtil.getUserId());
		}
		IPage<SpecialBaseWine> pages = specialBaseWineService.page(Condition.getPage(query), queryWrapper);
		return R.data(SpecialBaseWineWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 特调基酒
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入specialBaseWine")
	public R<IPage<SpecialBaseWineVO>> page(SpecialBaseWineVO specialBaseWine, Query query) {
		IPage<SpecialBaseWineVO> pages = specialBaseWineService.selectSpecialBaseWinePage(Condition.getPage(query), specialBaseWine);
		return R.data(pages);
	}

	/**
	 * 新增 特调基酒
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入specialBaseWine")
	public R save(@Valid @RequestBody SpecialBaseWine specialBaseWine) {
		return R.status(specialBaseWineService.save(specialBaseWine));
	}

	/**
	 * 修改 特调基酒
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入specialBaseWine")
	public R update(@Valid @RequestBody SpecialBaseWine specialBaseWine) {
		return R.status(specialBaseWineService.updateById(specialBaseWine));
	}

	/**
	 * 新增或修改 特调基酒
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入specialBaseWine")
	public R submit(@Valid @RequestBody SpecialBaseWine specialBaseWine) {
		return R.status(specialBaseWineService.saveOrUpdate(specialBaseWine));
	}

	
	/**
	 * 删除 特调基酒
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(specialBaseWineService.removeByIds(Func.toLongList(ids)));
	}

	
}
