/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.custom.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.custom.entity.SpecialBaseWine;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.custom.entity.SpecialFormula;
import org.springblade.modules.custom.vo.SpecialFormulaVO;
import org.springblade.modules.custom.wrapper.SpecialFormulaWrapper;
import org.springblade.modules.custom.service.ISpecialFormulaService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 特调配方 控制器
 *
 * @author BladeX
 * @since 2023-06-05
 */
@RestController
@AllArgsConstructor
@RequestMapping("custom/specialformula")
@Api(value = "特调配方", tags = "特调配方接口")
public class SpecialFormulaController extends BladeController {

	private final ISpecialFormulaService specialFormulaService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入specialFormula")
	public R<SpecialFormulaVO> detail(SpecialFormula specialFormula) {
		SpecialFormula detail = specialFormulaService.getOne(Condition.getQueryWrapper(specialFormula));
		return R.data(SpecialFormulaWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 特调配方
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入specialFormula")
	public R<IPage<SpecialFormulaVO>> list(SpecialFormula specialFormula, Query query) {
		QueryWrapper<SpecialFormula> queryWrapper = Condition.getQueryWrapper(specialFormula);
		if (!AuthUtil.getUserRole().contains("admin")) {
			queryWrapper.eq("create_user_id", AuthUtil.getUserId());
		}
		IPage<SpecialFormula> pages = specialFormulaService.page(Condition.getPage(query), queryWrapper);
		return R.data(SpecialFormulaWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 特调配方
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入specialFormula")
	public R<IPage<SpecialFormulaVO>> page(SpecialFormulaVO specialFormula, Query query) {
		IPage<SpecialFormulaVO> pages = specialFormulaService.selectSpecialFormulaPage(Condition.getPage(query), specialFormula);
		return R.data(pages);
	}

	/**
	 * 新增 特调配方
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入specialFormula")
	public R save(@Valid @RequestBody SpecialFormula specialFormula) {
		return R.status(specialFormulaService.save(specialFormula));
	}

	/**
	 * 修改 特调配方
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入specialFormula")
	public R update(@Valid @RequestBody SpecialFormula specialFormula) {
		return R.status(specialFormulaService.updateById(specialFormula));
	}

	/**
	 * 新增或修改 特调配方
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入specialFormula")
	public R submit(@Valid @RequestBody SpecialFormula specialFormula) {
		return R.status(specialFormulaService.saveOrUpdate(specialFormula));
	}

	
	/**
	 * 删除 特调配方
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(specialFormulaService.removeByIds(Func.toLongList(ids)));
	}

	
}
