/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.custom.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.custom.entity.TrademarkAuth;
import org.springblade.modules.custom.vo.TrademarkAuthVO;
import org.springblade.modules.custom.wrapper.TrademarkAuthWrapper;
import org.springblade.modules.custom.service.ITrademarkAuthService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 用户商标授权记录 控制器
 *
 * @author BladeX
 * @since 2023-05-31
 */
@RestController
@AllArgsConstructor
@RequestMapping("custom/trademarkauth")
@Api(value = "用户商标授权记录", tags = "用户商标授权记录接口")
public class TrademarkAuthController extends BladeController {

	private final ITrademarkAuthService trademarkAuthService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入trademarkAuth")
	public R<TrademarkAuthVO> detail(TrademarkAuth trademarkAuth) {
		TrademarkAuth detail = trademarkAuthService.getOne(Condition.getQueryWrapper(trademarkAuth));
		return R.data(TrademarkAuthWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 用户商标授权记录
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入trademarkAuth")
	public R<IPage<TrademarkAuthVO>> list(TrademarkAuth trademarkAuth, Query query) {
		IPage<TrademarkAuth> pages = trademarkAuthService.page(Condition.getPage(query), Condition.getQueryWrapper(trademarkAuth));
		return R.data(TrademarkAuthWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 用户商标授权记录
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入trademarkAuth")
	public R<IPage<TrademarkAuthVO>> page(TrademarkAuthVO trademarkAuth, Query query) {
		IPage<TrademarkAuthVO> pages = trademarkAuthService.selectTrademarkAuthPage(Condition.getPage(query), trademarkAuth);
		return R.data(pages);
	}

	/**
	 * 新增 用户商标授权记录
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入trademarkAuth")
	public R save(@Valid @RequestBody TrademarkAuth trademarkAuth) {
		return R.status(trademarkAuthService.save(trademarkAuth));
	}

	/**
	 * 修改 用户商标授权记录
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入trademarkAuth")
	public R update(@Valid @RequestBody TrademarkAuth trademarkAuth) {
		return R.status(trademarkAuthService.updateById(trademarkAuth));
	}

	/**
	 * 新增或修改 用户商标授权记录
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入trademarkAuth")
	public R submit(@Valid @RequestBody TrademarkAuth trademarkAuth) {
		return R.status(trademarkAuthService.saveOrUpdate(trademarkAuth));
	}

	
	/**
	 * 删除 用户商标授权记录
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(trademarkAuthService.removeByIds(Func.toLongList(ids)));
	}

	
}
