/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.custom.service.impl;

import org.springblade.modules.custom.entity.TrademarkAuth;
import org.springblade.modules.custom.vo.TrademarkAuthVO;
import org.springblade.modules.custom.mapper.TrademarkAuthMapper;
import org.springblade.modules.custom.service.ITrademarkAuthService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.modules.finance.entity.OrderTrademark;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.time.LocalDateTime;

/**
 * 用户商标授权记录 服务实现类
 *
 * @author BladeX
 * @since 2023-05-31
 */
@Service
public class TrademarkAuthServiceImpl extends ServiceImpl<TrademarkAuthMapper, TrademarkAuth> implements ITrademarkAuthService {

	@Override
	public IPage<TrademarkAuthVO> selectTrademarkAuthPage(IPage<TrademarkAuthVO> page, TrademarkAuthVO trademarkAuth) {
		return page.setRecords(baseMapper.selectTrademarkAuthPage(page, trademarkAuth));
	}

	@Override
	public void auth(OrderTrademark trademark) {
		TrademarkAuth auth = new TrademarkAuth();
		auth.setTrademarkId(trademark.getTrademarkId());
		auth.setUserId(trademark.getUserId());
		auth.setUsePeriod(LocalDateTime.now().plusDays(trademark.getAuthDays()));
		save(auth);
	}

	@Override
	public IPage<TrademarkAuthVO> authRecord(IPage page, Long userId, Integer type) {
		return page.setRecords(baseMapper.authRecord(page, userId, type));
	}

}
