/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.CustomWineDiy;
import org.springblade.modules.finance.vo.CustomWineDiyVO;
import org.springblade.modules.finance.wrapper.CustomWineDiyWrapper;
import org.springblade.modules.finance.service.ICustomWineDiyService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * DIY信息表 控制器
 *
 * @author BladeX
 * @since 2023-05-23
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/customwinediy")
@Api(value = "DIY信息表", tags = "DIY信息表接口")
public class CustomWineDiyController extends BladeController {

	private final ICustomWineDiyService customWineDiyService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入customWineDiy")
	public R<CustomWineDiyVO> detail(CustomWineDiy customWineDiy) {
		CustomWineDiy detail = customWineDiyService.getOne(Condition.getQueryWrapper(customWineDiy));
		return R.data(CustomWineDiyWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 DIY信息表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入customWineDiy")
	public R<IPage<CustomWineDiyVO>> list(CustomWineDiy customWineDiy, Query query) {
		IPage<CustomWineDiy> pages = customWineDiyService.page(Condition.getPage(query), Condition.getQueryWrapper(customWineDiy));
		return R.data(CustomWineDiyWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 DIY信息表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入customWineDiy")
	public R<IPage<CustomWineDiyVO>> page(CustomWineDiyVO customWineDiy, Query query) {
		IPage<CustomWineDiyVO> pages = customWineDiyService.selectCustomWineDiyPage(Condition.getPage(query), customWineDiy);
		return R.data(pages);
	}

	/**
	 * 新增 DIY信息表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入customWineDiy")
	public R save(@Valid @RequestBody CustomWineDiy customWineDiy) {
		return R.status(customWineDiyService.save(customWineDiy));
	}

	/**
	 * 修改 DIY信息表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入customWineDiy")
	public R update(@Valid @RequestBody CustomWineDiy customWineDiy) {
		return R.status(customWineDiyService.updateById(customWineDiy));
	}

	/**
	 * 新增或修改 DIY信息表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入customWineDiy")
	public R submit(@Valid @RequestBody CustomWineDiy customWineDiy) {
		return R.status(customWineDiyService.saveOrUpdate(customWineDiy));
	}

	
	/**
	 * 删除 DIY信息表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(customWineDiyService.removeByIds(Func.toLongList(ids)));
	}

	
}
