/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.CustomWineOrder;
import org.springblade.modules.finance.vo.CustomWineOrderVO;
import org.springblade.modules.finance.wrapper.CustomWineOrderWrapper;
import org.springblade.modules.finance.service.ICustomWineOrderService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 定制酒订单 控制器
 *
 * @author BladeX
 * @since 2023-02-14
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/customwineorder")
@Api(value = "定制酒订单", tags = "定制酒订单接口")
public class CustomWineOrderController extends BladeController {

	private final ICustomWineOrderService customWineOrderService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入customWineOrder")
	public R<CustomWineOrderVO> detail(CustomWineOrder customWineOrder) {
		CustomWineOrder detail = customWineOrderService.getOne(Condition.getQueryWrapper(customWineOrder));
		return R.data(CustomWineOrderWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 定制酒订单
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入customWineOrder")
	public R<IPage<CustomWineOrderVO>> list(CustomWineOrder customWineOrder, Query query) {
		IPage<CustomWineOrder> pages = customWineOrderService.page(Condition.getPage(query), Condition.getQueryWrapper(customWineOrder));
		return R.data(CustomWineOrderWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 定制酒订单
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入customWineOrder")
	public R<IPage<CustomWineOrderVO>> page(CustomWineOrderVO customWineOrder, Query query) {
		IPage<CustomWineOrderVO> pages = customWineOrderService.selectCustomWineOrderPage(Condition.getPage(query), customWineOrder);
		return R.data(pages);
	}

	/**
	 * 新增 定制酒订单
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入customWineOrder")
	public R save(@Valid @RequestBody CustomWineOrder customWineOrder) {
		return R.status(customWineOrderService.save(customWineOrder));
	}

	/**
	 * 修改 定制酒订单
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入customWineOrder")
	public R update(@Valid @RequestBody CustomWineOrder customWineOrder) {
		return R.status(customWineOrderService.updateById(customWineOrder));
	}

	/**
	 * 新增或修改 定制酒订单
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入customWineOrder")
	public R submit(@Valid @RequestBody CustomWineOrder customWineOrder) {
		return R.status(customWineOrderService.saveOrUpdate(customWineOrder));
	}

	
	/**
	 * 删除 定制酒订单
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(customWineOrderService.removeByIds(Func.toLongList(ids)));
	}

	
}
