/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.OrderSampleWine;
import org.springblade.modules.finance.vo.OrderSampleWineVO;
import org.springblade.modules.finance.wrapper.OrderSampleWineWrapper;
import org.springblade.modules.finance.service.IOrderSampleWineService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 样酒订单信息表 控制器
 *
 * @author BladeX
 * @since 2023-05-29
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/ordersamplewine")
@Api(value = "样酒订单信息表", tags = "样酒订单信息表接口")
public class OrderSampleWineController extends BladeController {

	private final IOrderSampleWineService orderSampleWineService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入orderSampleWine")
	public R<OrderSampleWineVO> detail(OrderSampleWine orderSampleWine) {
		OrderSampleWine detail = orderSampleWineService.getOne(Condition.getQueryWrapper(orderSampleWine));
		return R.data(OrderSampleWineWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 样酒订单信息表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入orderSampleWine")
	public R<IPage<OrderSampleWineVO>> list(OrderSampleWine orderSampleWine, Query query) {
		IPage<OrderSampleWine> pages = orderSampleWineService.page(Condition.getPage(query), Condition.getQueryWrapper(orderSampleWine));
		return R.data(OrderSampleWineWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 样酒订单信息表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入orderSampleWine")
	public R<IPage<OrderSampleWineVO>> page(OrderSampleWineVO orderSampleWine, Query query) {
		IPage<OrderSampleWineVO> pages = orderSampleWineService.selectOrderSampleWinePage(Condition.getPage(query), orderSampleWine);
		return R.data(pages);
	}

	/**
	 * 新增 样酒订单信息表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入orderSampleWine")
	public R save(@Valid @RequestBody OrderSampleWine orderSampleWine) {
		return R.status(orderSampleWineService.save(orderSampleWine));
	}

	/**
	 * 修改 样酒订单信息表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入orderSampleWine")
	public R update(@Valid @RequestBody OrderSampleWine orderSampleWine) {
		return R.status(orderSampleWineService.updateById(orderSampleWine));
	}

	/**
	 * 新增或修改 样酒订单信息表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入orderSampleWine")
	public R submit(@Valid @RequestBody OrderSampleWine orderSampleWine) {
		return R.status(orderSampleWineService.saveOrUpdate(orderSampleWine));
	}

	
	/**
	 * 删除 样酒订单信息表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(orderSampleWineService.removeByIds(Func.toLongList(ids)));
	}

	
}
