/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.OrderTrademark;
import org.springblade.modules.finance.vo.OrderTrademarkVO;
import org.springblade.modules.finance.wrapper.OrderTrademarkWrapper;
import org.springblade.modules.finance.service.IOrderTrademarkService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 商标授权订单表 控制器
 *
 * @author BladeX
 * @since 2023-06-03
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/ordertrademark")
@Api(value = "商标授权订单表", tags = "商标授权订单表接口")
public class OrderTrademarkController extends BladeController {

	private final IOrderTrademarkService orderTrademarkService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入orderTrademark")
	public R<OrderTrademarkVO> detail(OrderTrademark orderTrademark) {
		OrderTrademark detail = orderTrademarkService.getOne(Condition.getQueryWrapper(orderTrademark));
		return R.data(OrderTrademarkWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 商标授权订单表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入orderTrademark")
	public R<IPage<OrderTrademarkVO>> list(OrderTrademark orderTrademark, Query query) {
		IPage<OrderTrademark> pages = orderTrademarkService.page(Condition.getPage(query), Condition.getQueryWrapper(orderTrademark));
		return R.data(OrderTrademarkWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 商标授权订单表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入orderTrademark")
	public R<IPage<OrderTrademarkVO>> page(OrderTrademarkVO orderTrademark, Query query) {
		IPage<OrderTrademarkVO> pages = orderTrademarkService.selectOrderTrademarkPage(Condition.getPage(query), orderTrademark);
		return R.data(pages);
	}

	/**
	 * 新增 商标授权订单表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入orderTrademark")
	public R save(@Valid @RequestBody OrderTrademark orderTrademark) {
		return R.status(orderTrademarkService.save(orderTrademark));
	}

	/**
	 * 修改 商标授权订单表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入orderTrademark")
	public R update(@Valid @RequestBody OrderTrademark orderTrademark) {
		return R.status(orderTrademarkService.updateById(orderTrademark));
	}

	/**
	 * 新增或修改 商标授权订单表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入orderTrademark")
	public R submit(@Valid @RequestBody OrderTrademark orderTrademark) {
		return R.status(orderTrademarkService.saveOrUpdate(orderTrademark));
	}

	
	/**
	 * 删除 商标授权订单表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(orderTrademarkService.removeByIds(Func.toLongList(ids)));
	}

	
}
