/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.mapper;

import com.baomidou.mybatisplus.annotation.SqlParser;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.finance.vo.OrderVO;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import java.util.List;
import java.util.Map;

/**
 * 订单主表 Mapper 接口
 *
 * @author BladeX
 * @since 2023-02-14
 */
public interface OrderMapper extends BaseMapper<Order> {

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param order
	 * @return
	 */
	List<OrderVO> selectOrderPage(IPage page, OrderVO order);

    List<Order> selectTimeoutOrder(long seconds);

	/**
	 * 查询本年数据
	 * @return
	 */
	List<Map<String,Object>> selectCurrYear();

	/**
	 * 查询某几天前的数据
	 * @param dayNum 天数
	 * @return
	 */
	@SqlParser(filter=true)
	List<Map<String,Object>> selectStaticByDay(@Param("dayNum") Integer dayNum);


	/**
	 * 查询总订单数
	 * @return
	 */
	@Select("SELECT COUNT(1) FROM biz_order WHERE order_state not in (1,5)")
	Integer selectTotalOrderCount();

	/**
	 * 查询订单总金额
	 * @return
	 */
	@Select("SELECT SUM(total_amount) FROM biz_order WHERE order_state not in (1,5)")
	Double selectTotalOrderAmount();

	/**
	 * 查询今日总订单数
	 * @return
	 */
	@Select("SELECT COUNT(1) FROM biz_order WHERE order_state not in (1,5) and TO_DAYS(create_time) = TO_DAYS(NOW())")
	Integer selectTotalOrderCountToday();

	/**
	 * 查询今日订单总金额
	 * @return
	 */
	@Select("SELECT IFNULL(SUM(total_amount), 0.00) FROM biz_order WHERE  order_state not in (1,5) and TO_DAYS(create_time) = TO_DAYS(NOW())")
	Double selectTotalOrderAmountToday();
}
