/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.vo;

import io.swagger.annotations.ApiModelProperty;
import org.springblade.common.enums.OrderStateEnum;
import org.springblade.common.enums.OrderTypeEnum;
import org.springblade.common.enums.PaymentStateEnum;
import org.springblade.common.enums.PaymentTypeEnum;
import org.springblade.modules.custom.vo.BaseWineVO;
import org.springblade.modules.finance.entity.Order;
import lombok.Data;
import lombok.EqualsAndHashCode;
import io.swagger.annotations.ApiModel;
import org.springblade.modules.finance.entity.OrderGoods;

/**
 * 订单主表视图实体类
 *
 * @author BladeX
 * @since 2023-02-14
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "OrderVO对象", description = "订单主表")
public class OrderVO extends Order {

	private OrderGoods orderGoods;

	private OrderDetailVO orderDetail;

	private CustomWineOrderVO customWineOrderVO;

	private CustomWineDiyVO diyInfo;

	private BaseWineVO baseWineVO;

	@ApiModelProperty(value = "订单类型描述")
	private String orderTypeDesc;

	@ApiModelProperty(value = "订单状态描述")
	private String orderStateDesc;

	private String paymentModeDesc;

	private String paymentStateDesc;

	private long minutes;

	private long seconds;

	public String getPaymentModeDesc() {
		return PaymentTypeEnum.getNameByValue(getPaymentMode());
	}

	public String getOrderTypeDesc() {
		return OrderTypeEnum.getNameByValue(getOrderType());
	}

	public String getOrderStateDesc() {
		return OrderStateEnum.getNameByValue(getOrderState());
	}

	public String getPaymentStateDesc() {
		return PaymentStateEnum.getNameByValue(getPaymentState());
	}
}
