/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.mall.entity.CommentLike;
import org.springblade.modules.mall.vo.CommentLikeVO;
import org.springblade.modules.mall.wrapper.CommentLikeWrapper;
import org.springblade.modules.mall.service.ICommentLikeService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 评论点赞表 控制器
 *
 * @author BladeX
 * @since 2023-07-05
 */
@RestController
@AllArgsConstructor
@RequestMapping("mall/commentlike")
@Api(value = "评论点赞表", tags = "评论点赞表接口")
public class CommentLikeController extends BladeController {

	private final ICommentLikeService commentLikeService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入commentLike")
	public R<CommentLikeVO> detail(CommentLike commentLike) {
		CommentLike detail = commentLikeService.getOne(Condition.getQueryWrapper(commentLike));
		return R.data(CommentLikeWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 评论点赞表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入commentLike")
	public R<IPage<CommentLikeVO>> list(CommentLike commentLike, Query query) {
		IPage<CommentLike> pages = commentLikeService.page(Condition.getPage(query), Condition.getQueryWrapper(commentLike));
		return R.data(CommentLikeWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 评论点赞表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入commentLike")
	public R<IPage<CommentLikeVO>> page(CommentLikeVO commentLike, Query query) {
		IPage<CommentLikeVO> pages = commentLikeService.selectCommentLikePage(Condition.getPage(query), commentLike);
		return R.data(pages);
	}

	/**
	 * 新增 评论点赞表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入commentLike")
	public R save(@Valid @RequestBody CommentLike commentLike) {
		return R.status(commentLikeService.save(commentLike));
	}

	/**
	 * 修改 评论点赞表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入commentLike")
	public R update(@Valid @RequestBody CommentLike commentLike) {
		return R.status(commentLikeService.updateById(commentLike));
	}

	/**
	 * 新增或修改 评论点赞表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入commentLike")
	public R submit(@Valid @RequestBody CommentLike commentLike) {
		return R.status(commentLikeService.saveOrUpdate(commentLike));
	}

	
	/**
	 * 删除 评论点赞表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(commentLikeService.removeByIds(Func.toLongList(ids)));
	}

	
}
