/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.mall.entity.CommentMedia;
import org.springblade.modules.mall.vo.CommentMediaVO;
import org.springblade.modules.mall.wrapper.CommentMediaWrapper;
import org.springblade.modules.mall.service.ICommentMediaService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 评论媒体信息表 控制器
 *
 * @author BladeX
 * @since 2023-06-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("mall/commentmedia")
@Api(value = "评论媒体信息表", tags = "评论媒体信息表接口")
public class CommentMediaController extends BladeController {

	private final ICommentMediaService commentMediaService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入commentMedia")
	public R<CommentMediaVO> detail(CommentMedia commentMedia) {
		CommentMedia detail = commentMediaService.getOne(Condition.getQueryWrapper(commentMedia));
		return R.data(CommentMediaWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 评论媒体信息表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入commentMedia")
	public R<IPage<CommentMediaVO>> list(CommentMedia commentMedia, Query query) {
		IPage<CommentMedia> pages = commentMediaService.page(Condition.getPage(query), Condition.getQueryWrapper(commentMedia));
		return R.data(CommentMediaWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 评论媒体信息表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入commentMedia")
	public R<IPage<CommentMediaVO>> page(CommentMediaVO commentMedia, Query query) {
		IPage<CommentMediaVO> pages = commentMediaService.selectCommentMediaPage(Condition.getPage(query), commentMedia);
		return R.data(pages);
	}

	/**
	 * 新增 评论媒体信息表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入commentMedia")
	public R save(@Valid @RequestBody CommentMedia commentMedia) {
		return R.status(commentMediaService.save(commentMedia));
	}

	/**
	 * 修改 评论媒体信息表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入commentMedia")
	public R update(@Valid @RequestBody CommentMedia commentMedia) {
		return R.status(commentMediaService.updateById(commentMedia));
	}

	/**
	 * 新增或修改 评论媒体信息表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入commentMedia")
	public R submit(@Valid @RequestBody CommentMedia commentMedia) {
		return R.status(commentMediaService.saveOrUpdate(commentMedia));
	}

	
	/**
	 * 删除 评论媒体信息表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(commentMediaService.removeByIds(Func.toLongList(ids)));
	}

	
}
