/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.mall.entity.CouponGoods;
import org.springblade.modules.mall.vo.CouponGoodsVO;
import org.springblade.modules.mall.service.ICouponGoodsService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 商品优惠券关联表 控制器
 *
 * @author BladeX
 * @since 2023-05-04
 */
@RestController
@AllArgsConstructor
@RequestMapping("mall/coupongoods")
@Api(value = "商品优惠券关联表", tags = "商品优惠券关联表接口")
public class CouponGoodsController extends BladeController {

	private final ICouponGoodsService couponGoodsService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入couponGoods")
	public R<CouponGoods> detail(CouponGoods couponGoods) {
		CouponGoods detail = couponGoodsService.getOne(Condition.getQueryWrapper(couponGoods));
		return R.data(detail);
	}

	/**
	 * 分页 商品优惠券关联表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入couponGoods")
	public R<IPage<CouponGoods>> list(CouponGoods couponGoods, Query query) {
		IPage<CouponGoods> pages = couponGoodsService.page(Condition.getPage(query), Condition.getQueryWrapper(couponGoods));
		return R.data(pages);
	}

	/**
	 * 自定义分页 商品优惠券关联表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入couponGoods")
	public R<IPage<CouponGoodsVO>> page(CouponGoodsVO couponGoods, Query query) {
		IPage<CouponGoodsVO> pages = couponGoodsService.selectCouponGoodsPage(Condition.getPage(query), couponGoods);
		return R.data(pages);
	}

	/**
	 * 新增 商品优惠券关联表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入couponGoods")
	public R save(@Valid @RequestBody CouponGoods couponGoods) {
		return R.status(couponGoodsService.save(couponGoods));
	}

	/**
	 * 修改 商品优惠券关联表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入couponGoods")
	public R update(@Valid @RequestBody CouponGoods couponGoods) {
		return R.status(couponGoodsService.updateById(couponGoods));
	}

	/**
	 * 新增或修改 商品优惠券关联表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入couponGoods")
	public R submit(@Valid @RequestBody CouponGoods couponGoods) {
		return R.status(couponGoodsService.saveOrUpdate(couponGoods));
	}

	
	/**
	 * 删除 商品优惠券关联表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(couponGoodsService.removeByIds(Func.toLongList(ids)));
	}

	
}
