/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.util.Assert;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.mall.entity.SeckillGoods;
import org.springblade.modules.mall.vo.SeckillGoodsVO;
import org.springblade.modules.mall.service.ISeckillGoodsService;
import org.springblade.core.boot.ctrl.BladeController;

import java.util.List;

/**
 * 秒杀商品表 控制器
 *
 * @author BladeX
 * @since 2023-05-04
 */
@RestController
@AllArgsConstructor
@RequestMapping("mall/seckillgoods")
@Api(value = "秒杀商品表", tags = "秒杀商品表接口")
public class SeckillGoodsController extends BladeController {

	private final ISeckillGoodsService seckillGoodsService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入seckillGoods")
	public R<SeckillGoods> detail(SeckillGoods seckillGoods) {
		SeckillGoods detail = seckillGoodsService.getOne(Condition.getQueryWrapper(seckillGoods));
		return R.data(detail);
	}

	/**
	 * 分页 秒杀商品表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入seckillGoods")
	public R<IPage<SeckillGoods>> list(SeckillGoods seckillGoods, Query query) {
		IPage<SeckillGoods> pages = seckillGoodsService.page(Condition.getPage(query), Condition.getQueryWrapper(seckillGoods));
		return R.data(pages);
	}

	/**
	 * 自定义分页 秒杀商品表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入seckillGoods")
	public R<IPage<SeckillGoodsVO>> page(SeckillGoodsVO seckillGoods, Query query) {
		IPage<SeckillGoodsVO> pages = seckillGoodsService.selectSeckillGoodsPage(Condition.getPage(query), seckillGoods);
		return R.data(pages);
	}

	/**
	 * 新增 秒杀商品表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入seckillGoods")
	public R save(@Valid @RequestBody SeckillGoods seckillGoods) {
		return R.status(seckillGoodsService.save(seckillGoods));
	}

	/**
	 * 修改 秒杀商品表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入seckillGoods")
	public R update(@Valid @RequestBody SeckillGoods seckillGoods) {
		return R.status(seckillGoodsService.updateById(seckillGoods));
	}

	/**
	 * 新增或修改 秒杀商品表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入seckillGoods")
	public R submit(@RequestBody List<SeckillGoods> seckillGoods) {
		Assert.notEmpty(seckillGoods, "参数不能为空");
		seckillGoodsService.addSeckillGoods(seckillGoods);                      
		return R.success("ok");
	}

	
	/**
	 * 删除 秒杀商品表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(seckillGoodsService.removeByIds(Func.toLongList(ids)));
	}


	@GetMapping("/")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "获取秒杀商品")
	public R<List<SeckillGoodsVO>> goods(@ApiParam(value = "秒杀场次ID")
										 @RequestParam(value = "seckkillRoundId") Long seckkillRoundId, Query query) {
		return data(seckillGoodsService.getGoods(Condition.getPage(query), seckkillRoundId));
	}

	
}
