/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.service;

import org.apache.poi.ss.formula.functions.T;
import org.springblade.modules.api.vo.CouponQuantityVO;
import org.springblade.modules.mall.entity.CouponUser;
import org.springblade.modules.mall.vo.CouponUserVO;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.core.metadata.IPage;

/**
 * 用户优惠券关联表 服务类
 *
 * @author BladeX
 * @since 2023-05-04
 */
public interface ICouponUserService extends IService<CouponUser> {

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param couponUser
	 * @return
	 */
	IPage<CouponUserVO> selectCouponUserPage(IPage<CouponUserVO> page, CouponUserVO couponUser);

	/**
	 * 查询用户优惠券数量
	 * @param userId
	 * @return
	 */
	CouponQuantityVO quantity(Long userId);

	/**
	 * 用户优惠券列表
	 * @param page
	 * @param state
	 * @param userId
	 * @return
	 */
	IPage<CouponUserVO> userCouponList(IPage<CouponUserVO> page, Integer state, Long userId);

	/**
	 * 领取优惠券
	 * @param couponId
	 * @param userId
	 */
	void receive(Long couponId, Long userId);

	/**
	 * 使用优惠券
	 * @param orderNo 订单号或者流水号
	 * @param couponUserId
	 */
	void use(String orderNo, Long couponUserId);
}
