/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.modules.mall.entity.GoodsParams;
import org.springblade.modules.mall.mapper.GoodsParamsMapper;
import org.springblade.modules.mall.service.IGoodsParamsService;
import org.springblade.modules.mall.vo.GoodsParamsVO;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 商品参数表 服务实现类
 *
 * @author BladeX
 * @since 2022-05-07
 */
@Service
public class GoodsParamsServiceImpl extends ServiceImpl<GoodsParamsMapper, GoodsParams> implements IGoodsParamsService {

	@Override
	public IPage<GoodsParamsVO> selectGoodsParamsPage(IPage<GoodsParamsVO> page, GoodsParamsVO goodsParams) {
		return page.setRecords(baseMapper.selectGoodsParamsPage(page, goodsParams));
	}

	@Override
	public void deleteByGoodsIds(List<Long> goodsIds) {
		baseMapper.delete(Wrappers.lambdaQuery(GoodsParams.class).in(GoodsParams::getGoodsId, goodsIds));
	}

	@Override
	public List<GoodsParams> getByGoodsId(Long goodsId) {
		List<GoodsParams> list = this.list(Wrappers.lambdaQuery(GoodsParams.class).
			eq(GoodsParams::getGoodsId, goodsId).orderByAsc(GoodsParams::getSort));
		return list;
	}

	@Override
	public void addDefaultParam(Long goodsId) {
		List<GoodsParams> list = new ArrayList<>();
		GoodsParams params1 = new GoodsParams("名称", "", goodsId, 1);
		GoodsParams params2 = new GoodsParams("酒精度", "", goodsId, 2);
		GoodsParams params3 = new GoodsParams("净含量", "", goodsId, 3);
		GoodsParams params4 = new GoodsParams("原料", "", goodsId, 4);
		GoodsParams params5 = new GoodsParams("贮藏条件", "", goodsId, 5);
		GoodsParams params6 = new GoodsParams("香型", "", goodsId, 6);
		GoodsParams params7 = new GoodsParams("产地", "", goodsId, 7);
		GoodsParams params8 = new GoodsParams("生产许可证号", "", goodsId, 8);
		GoodsParams params9 = new GoodsParams("产品执行标准号", "", goodsId, 9);
		list.add(params1);
		list.add(params2);
		list.add(params3);
		list.add(params4);
		list.add(params5);
		list.add(params6);
		list.add(params7);
		list.add(params8);
		list.add(params9);
		saveBatch(list);
	}

}
