/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mall.wrapper;

import cn.hutool.core.date.LocalDateTimeUtil;
import org.springblade.core.mp.support.BaseEntityWrapper;
import org.springblade.core.tool.utils.BeanUtil;
import org.springblade.modules.mall.entity.SeckillRound;
import org.springblade.modules.mall.vo.SeckillRoundVO;

import java.time.LocalTime;
import java.util.Objects;

/**
 * 限时秒杀场次表包装类,返回视图层所需的字段
 *
 * @author BladeX
 * @since 2023-05-04
 */
public class SeckillRoundWrapper extends BaseEntityWrapper<SeckillRound, SeckillRoundVO>  {

	public static SeckillRoundWrapper build() {
		return new SeckillRoundWrapper();
 	}

	@Override
	public SeckillRoundVO entityVO(SeckillRound seckillRound) {
		SeckillRoundVO seckillRoundVO = Objects.requireNonNull(BeanUtil.copy(seckillRound, SeckillRoundVO.class));
		LocalTime localTime = LocalTime.now();
		boolean before = localTime.isBefore(seckillRoundVO.getEndTime());
		if (!before) {
			seckillRoundVO.setState(3);
		} else {
			boolean after = localTime.isAfter(seckillRoundVO.getStartTime());
			if (!after) {
				seckillRoundVO.setState(2);
			} else {
				seckillRoundVO.setState(1);	
			}
		}
		return seckillRoundVO;
	}

}
