/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.platform.entity.BalanceRecord;
import org.springblade.modules.platform.vo.BalanceRecordVO;
import org.springblade.modules.platform.wrapper.BalanceRecordWrapper;
import org.springblade.modules.platform.service.IBalanceRecordService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 余额记录表 控制器
 *
 * @author BladeX
 * @since 2023-07-10
 */
@RestController
@AllArgsConstructor
@RequestMapping("platform/balancerecord")
@Api(value = "余额记录表", tags = "余额记录表接口")
public class BalanceRecordController extends BladeController {

	private final IBalanceRecordService balanceRecordService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入balanceRecord")
	public R<BalanceRecordVO> detail(BalanceRecord balanceRecord) {
		BalanceRecord detail = balanceRecordService.getOne(Condition.getQueryWrapper(balanceRecord));
		return R.data(BalanceRecordWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 余额记录表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入balanceRecord")
	public R<IPage<BalanceRecordVO>> list(BalanceRecord balanceRecord, Query query) {
		IPage<BalanceRecord> pages = balanceRecordService.page(Condition.getPage(query), Condition.getQueryWrapper(balanceRecord));
		return R.data(BalanceRecordWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 余额记录表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入balanceRecord")
	public R<IPage<BalanceRecordVO>> page(BalanceRecordVO balanceRecord, Query query) {
		IPage<BalanceRecordVO> pages = balanceRecordService.selectBalanceRecordPage(Condition.getPage(query), balanceRecord);
		return R.data(pages);
	}

	/**
	 * 新增 余额记录表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入balanceRecord")
	public R save(@Valid @RequestBody BalanceRecord balanceRecord) {
		return R.status(balanceRecordService.save(balanceRecord));
	}

	/**
	 * 修改 余额记录表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入balanceRecord")
	public R update(@Valid @RequestBody BalanceRecord balanceRecord) {
		return R.status(balanceRecordService.updateById(balanceRecord));
	}

	/**
	 * 新增或修改 余额记录表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入balanceRecord")
	public R submit(@Valid @RequestBody BalanceRecord balanceRecord) {
		return R.status(balanceRecordService.saveOrUpdate(balanceRecord));
	}

	
	/**
	 * 删除 余额记录表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(balanceRecordService.removeByIds(Func.toLongList(ids)));
	}

	
}
