/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.platform.entity.MerchantSettle;
import org.springblade.modules.platform.vo.MerchantSettleVO;
import org.springblade.modules.platform.wrapper.MerchantSettleWrapper;
import org.springblade.modules.platform.service.IMerchantSettleService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 商家入驻信息表 控制器
 *
 * @author BladeX
 * @since 2023-05-31
 */
@RestController
@AllArgsConstructor
@RequestMapping("platform/merchantsettle")
@Api(value = "商家入驻信息表", tags = "商家入驻信息表接口")
public class MerchantSettleController extends BladeController {

	private final IMerchantSettleService merchantSettleService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入merchantSettle")
	public R<MerchantSettleVO> detail(MerchantSettle merchantSettle) {
		MerchantSettle detail = merchantSettleService.getOne(Condition.getQueryWrapper(merchantSettle));
		return R.data(MerchantSettleWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 商家入驻信息表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入merchantSettle")
	public R<IPage<MerchantSettleVO>> list(MerchantSettle merchantSettle, Query query) {
		IPage<MerchantSettle> pages = merchantSettleService.page(Condition.getPage(query), Condition.getQueryWrapper(merchantSettle));
		return R.data(MerchantSettleWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 商家入驻信息表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入merchantSettle")
	public R<IPage<MerchantSettleVO>> page(MerchantSettleVO merchantSettle, Query query) {
		IPage<MerchantSettleVO> pages = merchantSettleService.selectMerchantSettlePage(Condition.getPage(query), merchantSettle);
		return R.data(pages);
	}

	/**
	 * 新增 商家入驻信息表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入merchantSettle")
	public R save(@Valid @RequestBody MerchantSettle merchantSettle) {
		return R.status(merchantSettleService.save(merchantSettle));
	}

	/**
	 * 修改 商家入驻信息表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入merchantSettle")
	public R update(@Valid @RequestBody MerchantSettle merchantSettle) {
		return R.status(merchantSettleService.updateById(merchantSettle));
	}

	/**
	 * 新增或修改 商家入驻信息表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入merchantSettle")
	public R submit(@Valid @RequestBody MerchantSettle merchantSettle) {
		return R.status(merchantSettleService.saveOrUpdate(merchantSettle));
	}

	
	/**
	 * 删除 商家入驻信息表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(merchantSettleService.removeByIds(Func.toLongList(ids)));
	}

	
}
