/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.platform.entity.NoticeRead;
import org.springblade.modules.platform.vo.NoticeReadVO;
import org.springblade.modules.platform.wrapper.NoticeReadWrapper;
import org.springblade.modules.platform.service.INoticeReadService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 系统通知阅读记录 控制器
 *
 * @author BladeX
 * @since 2023-07-06
 */
@RestController
@AllArgsConstructor
@RequestMapping("desk/noticeread")
@Api(value = "系统通知阅读记录", tags = "系统通知阅读记录接口")
public class NoticeReadController extends BladeController {

	private final INoticeReadService noticeReadService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入noticeRead")
	public R<NoticeReadVO> detail(NoticeRead noticeRead) {
		NoticeRead detail = noticeReadService.getOne(Condition.getQueryWrapper(noticeRead));
		return R.data(NoticeReadWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 系统通知阅读记录
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入noticeRead")
	public R<IPage<NoticeReadVO>> list(NoticeRead noticeRead, Query query) {
		IPage<NoticeRead> pages = noticeReadService.page(Condition.getPage(query), Condition.getQueryWrapper(noticeRead));
		return R.data(NoticeReadWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 系统通知阅读记录
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入noticeRead")
	public R<IPage<NoticeReadVO>> page(NoticeReadVO noticeRead, Query query) {
		IPage<NoticeReadVO> pages = noticeReadService.selectNoticeReadPage(Condition.getPage(query), noticeRead);
		return R.data(pages);
	}

	/**
	 * 新增 系统通知阅读记录
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入noticeRead")
	public R save(@Valid @RequestBody NoticeRead noticeRead) {
		return R.status(noticeReadService.save(noticeRead));
	}

	/**
	 * 修改 系统通知阅读记录
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入noticeRead")
	public R update(@Valid @RequestBody NoticeRead noticeRead) {
		return R.status(noticeReadService.updateById(noticeRead));
	}

	/**
	 * 新增或修改 系统通知阅读记录
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入noticeRead")
	public R submit(@Valid @RequestBody NoticeRead noticeRead) {
		return R.status(noticeReadService.saveOrUpdate(noticeRead));
	}

	
	/**
	 * 删除 系统通知阅读记录
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(noticeReadService.removeByIds(Func.toLongList(ids)));
	}

	
}
