/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.platform.entity.UserMessage;
import org.springblade.modules.platform.vo.UserMessageVO;
import org.springblade.modules.platform.wrapper.UserMessageWrapper;
import org.springblade.modules.platform.service.IUserMessageService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 用户消息表 控制器
 *
 * @author BladeX
 * @since 2023-07-06
 */
@RestController
@AllArgsConstructor
@RequestMapping("platform/usermessage")
@Api(value = "用户消息表", tags = "用户消息表接口")
public class UserMessageController extends BladeController {

	private final IUserMessageService userMessageService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入userMessage")
	public R<UserMessageVO> detail(UserMessage userMessage) {
		UserMessage detail = userMessageService.getOne(Condition.getQueryWrapper(userMessage));
		return R.data(UserMessageWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 用户消息表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入userMessage")
	public R<IPage<UserMessageVO>> list(UserMessage userMessage, Query query) {
		IPage<UserMessage> pages = userMessageService.page(Condition.getPage(query), Condition.getQueryWrapper(userMessage));
		return R.data(UserMessageWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 用户消息表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入userMessage")
	public R<IPage<UserMessageVO>> page(UserMessageVO userMessage, Query query) {
		IPage<UserMessageVO> pages = userMessageService.selectUserMessagePage(Condition.getPage(query), userMessage);
		return R.data(pages);
	}

	/**
	 * 新增 用户消息表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入userMessage")
	public R save(@Valid @RequestBody UserMessage userMessage) {
		return R.status(userMessageService.save(userMessage));
	}

	/**
	 * 修改 用户消息表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入userMessage")
	public R update(@Valid @RequestBody UserMessage userMessage) {
		return R.status(userMessageService.updateById(userMessage));
	}

	/**
	 * 新增或修改 用户消息表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入userMessage")
	public R submit(@Valid @RequestBody UserMessage userMessage) {
		return R.status(userMessageService.saveOrUpdate(userMessage));
	}

	
	/**
	 * 删除 用户消息表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(userMessageService.removeByIds(Func.toLongList(ids)));
	}

	
}
